@@ -1,16 +1,14 @@
-InternalSES.temporal = function(target, reps, group, dataset, max_k = 3, threshold = 0.05, test = NULL, ini, wei = NULL, equal_case = 3, user_test = NULL, dataInfo = NULL, 
-                                hash = FALSE, varsize, stat_hash, pvalue_hash, targetID, slopes, ncores, logged)
-{
+InternalSES.temporal = function(target, reps, group, dataset, max_k = 3, threshold = 0.05, test = NULL, ini, wei = NULL, user_test = NULL, 
+                                hash = FALSE, varsize, stat_hash, pvalue_hash, targetID, slopes, ncores) {
   #get the current time
   runtime = proc.time();
   #univariate feature selection test
   if ( is.null(ini) ) {
-    univariateModels = univariateScore.temporal(target , reps, group, dataset, test, wei = wei, dataInfo = dataInfo, targetID = targetID, slopes = slopes, ncores = ncores);
+    univariateModels = univariateScore.temporal(target, reps, group, dataset, test, wei = wei, targetID = targetID, slopes = slopes, ncores = ncores);
   } else   univariateModels = ini
   
   pvalues = univariateModels$pvalue;
   stats = univariateModels$stat;
-  flags = univariateModels$flag;
   stat_hash = univariateModels$stat_hash;
   pvalue_hash = univariateModels$pvalue_hash;
   #if we dont have any associations , return
@@ -28,13 +26,11 @@ InternalSES.temporal = function(target, reps, group, dataset, max_k = 3, thresho
     results$hashObject = NULL;
     class(results$hashObject) = 'list';
     class(results$univ) = 'list';
-    if (logged) {
-      results$pvalues = pvalues;
-    } else  results$pvalues = exp(pvalues);
+    results$pvalues = pvalues;
     results$stats = stats;
     results$univ = univariateModels;
     results$max_k = max_k;
-    results$threshold = exp(threshold);
+    results$threshold = threshold;
     runtime = proc.time() - runtime;
     results$runtime = runtime;
     results$slope = slopes
@@ -47,7 +43,7 @@ InternalSES.temporal = function(target, reps, group, dataset, max_k = 3, thresho
   queues = vector('list' , varsize);
   queues <- lapply(1:varsize , function(i){queues[[i]] = i;})
   #select the variable with the highest association
-  selectedVar = which(flags == 1 & stats == stats[[which.max(stats)]]);
+  selectedVar = which( stats == stats[[which.max(stats)]] );
   selectedVars[selectedVar] = 1;
   selectedVarsOrder[selectedVar] = 1; #CHANGE
   #lets check the first selected var
@@ -63,7 +59,7 @@ InternalSES.temporal = function(target, reps, group, dataset, max_k = 3, thresho
   
   while(loop)  {
     #lets find the equivalences
-    IdEq_results <- IdentifyEquivalence.temporal(equal_case , queues , target , reps, group, dataset , test , wei, threshold , max_k , selectedVars , pvalues , stats , remainingVars , univariateModels, selectedVarsOrder, hash=hash, dataInfo, stat_hash=stat_hash, pvalue_hash=pvalue_hash, slopes = slopes);
+    IdEq_results <- IdentifyEquivalence.temporal(queues, target, reps, group, dataset, test, wei, threshold, max_k, selectedVars, pvalues, stats, remainingVars, univariateModels, selectedVarsOrder, hash=hash, stat_hash=stat_hash, pvalue_hash=pvalue_hash, slopes = slopes);
     queues = IdEq_results$queues;
     selectedVars = IdEq_results$selectedVars;
     remainingVars = IdEq_results$remainingVars;
@@ -72,7 +68,7 @@ InternalSES.temporal = function(target, reps, group, dataset, max_k = 3, thresho
     stat_hash=IdEq_results$stat_hash;
     pvalue_hash=IdEq_results$pvalue_hash;
     #lets find the variable with the max min association
-    max_min_results = max_min_assoc.temporal(target, reps, group, dataset, test, wei, threshold, max_k, selectedVars, pvalues, stats, remainingVars, univariateModels, selectedVarsOrder, hash=hash, dataInfo, stat_hash=stat_hash, pvalue_hash=pvalue_hash, slopes = slopes);
+    max_min_results = max_min_assoc.temporal(target, reps, group, dataset, test, wei, threshold, max_k, selectedVars, pvalues, stats, remainingVars, univariateModels, selectedVarsOrder, hash=hash, stat_hash=stat_hash, pvalue_hash=pvalue_hash, slopes = slopes);
     selectedVar = max_min_results$selected_var;
     selectedPvalue = max_min_results$selected_pvalue;
     remainingVars = max_min_results$remainingVars;
@@ -90,7 +86,7 @@ InternalSES.temporal = function(target, reps, group, dataset, max_k = 3, thresho
   }
   
   #lets find the variables to be discarded
-  IdEq_results <- IdentifyEquivalence.temporal(equal_case, queues, target, reps, group, dataset, test, wei, threshold, max_k, selectedVars, pvalues, stats, remainingVars, univariateModels, selectedVarsOrder, hash=hash, dataInfo, stat_hash=stat_hash, pvalue_hash=pvalue_hash, slopes = slopes);
+  IdEq_results <- IdentifyEquivalence.temporal(queues, target, reps, group, dataset, test, wei, threshold, max_k, selectedVars, pvalues, stats, remainingVars, univariateModels, selectedVarsOrder, hash=hash, stat_hash=stat_hash, pvalue_hash=pvalue_hash, slopes = slopes);
   queues = IdEq_results$queues;
   selectedVars = IdEq_results$selectedVars;
   pvalues = IdEq_results$pvalues;
@@ -124,21 +120,13 @@ InternalSES.temporal = function(target, reps, group, dataset, max_k = 3, thresho
   hashObject$pvalue_hash = pvalue_hash;
   results$hashObject = hashObject;
   class(results$hashObject) = 'list';
-  if (logged) {
-    results$pvalues = pvalues;
-  } else  results$pvalues = exp(pvalues);
+  results$pvalues = pvalues;
   results$stats = stats;
   results$univ = univariateModels;
-  #   results$all_queues = all_queues;
-  #   already known
-  #   results$data = dataset;
-  #   results$target = target;
-  #   results$test = test;
   results$max_k = max_k;
-  results$threshold = exp(threshold);
+  results$threshold = threshold;
   runtime = proc.time() - runtime;
   results$runtime = runtime;
   results$slope = slopes
-  
   return(results);
 }
