@@ -1,4 +1,4 @@
-censIndCR = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo=NULL, univariateModels=NULL, hash = FALSE, stat_hash=NULL, pvalue_hash=NULL,robust=FALSE){
+censIndCR = function(target, dataset, xIndex, csIndex, wei = NULL, univariateModels=NULL, hash = FALSE, stat_hash=NULL, pvalue_hash=NULL){
   # Conditional independence test based on the Log Likelihood ratio test
   if ( !survival::is.Surv(target) )   stop('The survival test can not be performed without a Surv object target');
   csIndex[ which( is.na(csIndex) ) ] = 0;
@@ -11,16 +11,14 @@ censIndCR = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo=NULL
     if ( is.null(stat_hash[[key]]) == FALSE ) {
       stat = stat_hash[[key]];
       pvalue = pvalue_hash[[key]];
-      flag = 1;
-      results <- list(pvalue = pvalue, stat = stat, flag = flag, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+      results <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
       return(results);
     }
   }
   #initialization: these values will be returned whether the test cannot be carried out
   pvalue = log(1);
   stat = 0;
-  flag = 0;
-  results <- list(pvalue = pvalue, stat = stat, flag = flag, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+  results <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
   cox_results = NULL;
   cox_results_full = NULL;
   #timeIndex = dim(dataset)[2];
@@ -43,11 +41,9 @@ censIndCR = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo=NULL
         dF = res[2, 3]
         pvalue = pchisq(stat, dF, lower.tail = FALSE, log.p = TRUE)
       }  
-      flag = 1;
       if ( is.na(pvalue) || is.na(stat) ) {
         pvalue = log(1);
         stat = 0;
-        flag = 0;
       } else {
         #update hash objects
         if( hash )  {
@@ -56,6 +52,6 @@ censIndCR = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo=NULL
         }
       }
       #testerrorcaseintrycatch(4);
-      results <- list(pvalue = pvalue, stat = stat, flag = flag , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+      results <- list(pvalue = pvalue, stat = stat,  stat_hash=stat_hash, pvalue_hash=pvalue_hash);
       return(results);
 }
\ No newline at end of file
