@@ -1,10 +1,9 @@
-fbed.multinom <- function(y, x, alpha = 0.05, wei = NULL, K = 0) { 
+fbed.multinom <- function(y, x, alpha = 0.05, univ = NULL, wei = NULL, K = 0) { 
   dm <- dim(x)
   p <- dm[2]
   ind <- 1:p
   sig <- log(alpha)
   fit1 <- nnet::multinom(y ~ 1, weights = wei, trace = FALSE)
-  dof1 <- length( coef(fit1) ) 
   lik1 <- logLik(fit1)
   lik2 <- numeric(p)
   dof <- numeric(p)
@@ -14,15 +13,24 @@ fbed.multinom <- function(y, x, alpha = 0.05, wei = NULL, K = 0) {
   pva <- NULL
   
   runtime <- proc.time()
-  
-  for ( i in ind ) {
-    fit2 <- nnet::multinom( y ~ x[, i], weights = wei, trace = FALSE )
-    lik2[i] <- logLik( fit2 )
-    dof[i] <- length( coef(fit2) ) 
-  }
-  n.tests <- p
-  stat <- 2 * (lik2 - lik1)
-  pval <- pchisq(stat, dof - dof1, lower.tail = FALSE, log.p = TRUE)
+  if ( is.null(univ) ) {
+    d1 <- length( unique(y) ) - 1 
+    for ( i in ind ) {
+      fit2 <- nnet::multinom( y ~ x[, i], weights = wei, trace = FALSE )
+      lik2[i] <- logLik( fit2 )
+	  dof[i] <- length( coef(fit2) )
+    }
+    n.tests <- p
+    stat <- 2 * (lik2 - lik1)
+    pval <- pchisq(stat, dof - d1, lower.tail = FALSE, log.p = TRUE)
+    univ$stat <- stat
+    univ$pvalue <- pval
+  } else {
+    stat <- univ$stat
+    pval <- univ$pvalue
+    n.tests <- 0
+    lik2 <- univ$stat + 2 * lik1
+  }  
   s <- which(pval < sig)
 
     if ( length(s) > 0 ) {
@@ -30,7 +38,7 @@ fbed.multinom <- function(y, x, alpha = 0.05, wei = NULL, K = 0) {
       sela <- sel
       s <- s[ - which(s == sel) ]
       lik1 <- lik2[sel] 
-      d1 <- dof[sel] 
+      d1 <- dim( model.matrix( y~., data.frame(x[, sel]) ) )[2] - 1
       sa <- stat[sel]
       pva <- pval[sel]
       lik2 <- rep( lik1, p )
@@ -215,6 +223,6 @@ fbed.multinom <- function(y, x, alpha = 0.05, wei = NULL, K = 0) {
   colnames(res) <- c("Vars", "stat", "log p-value")
   rownames(info) <- paste("K=", 1:length(card)- 1, sep = "")
   colnames(info) <- c("Number of vars", "Number of tests")
-  list(res = res, info = info, runtime = runtime)
+  list(univ = univ, res = res, info = info, runtime = runtime)
 }
  
\ No newline at end of file
