@@ -1,11 +1,10 @@
-fbed.zip <- function(y, x, alpha = 0.05, wei = NULL, K = 0) { 
+fbed.zip <- function(y, x, alpha = 0.05, univ = NULL, wei = NULL, K = 0) { 
   dm <- dim(x)
   n <- dm[1]
   p <- dm[2]
   ind <- 1:p
   sig <- log(alpha)
   lik2 <- numeric(p)
-  dof <- numeric(p)
   sela <- NULL
   card <- 0
   sa <- NULL
@@ -20,10 +19,19 @@ fbed.zip <- function(y, x, alpha = 0.05, wei = NULL, K = 0) {
   }
   runtime <- proc.time()
   
-  mod <- zip.regs(y, x, wei, logged = TRUE)
-  n.tests <- p
-  stat <- mod[, 1]
-  pval <- mod[, 2]
+  if ( is.null(univ) ) {
+    mod <- zip.regs(y, x, wei, logged = TRUE)
+    n.tests <- p
+    stat <- mod[, 1]
+    pval <- mod[, 2]
+    univ <- list()
+    univ$stat <- stat
+    univ$pvalue <- pval
+  } else {
+    n.tests <- 0
+    stat <- univ$stat
+    pval <- univ$pvalue
+  }  
   s <- which(pval < sig)
 
     if ( length(s) > 0 ) {
@@ -31,7 +39,7 @@ fbed.zip <- function(y, x, alpha = 0.05, wei = NULL, K = 0) {
       sela <- sel
       s <- s[ - which(s == sel) ]
       lik1 <- stat[sel] + mo 
-      d1 <- dof[sel] 
+      d1 <- dim( model.matrix( y~., data.frame(x[, sel]) ) )[2] - 1
       sa <- stat[sel]
       pva <- pval[sel]
       lik2 <- rep( lik1, p )
@@ -217,6 +225,6 @@ fbed.zip <- function(y, x, alpha = 0.05, wei = NULL, K = 0) {
   colnames(res) <- c("Vars", "stat", "log p-value")
   rownames(info) <- paste("K=", 1:length(card)- 1, sep = "")
   colnames(info) <- c("Number of vars", "Number of tests")
-  list(res = res, info = info, runtime = runtime)
+  list(univ = univ, res = res, info = info, runtime = runtime)
 }
  
\ No newline at end of file
