@@ -1,5 +1,5 @@
-perm.mmpc = function(target, dataset, max_k = 3, threshold = 0.05, test = NULL, ini = NULL, wei = NULL, user_test = NULL, hash=FALSE, hashObject=NULL, robust = FALSE, R = 999, ncores = 1, backward = FALSE)
-{
+perm.mmpc = function(target, dataset, max_k = 3, threshold = 0.05, test = NULL, ini = NULL, wei = NULL, user_test = NULL, 
+                     hash=FALSE, hashObject=NULL, R = 999, ncores = 1, backward = FALSE) {
   ##############################
   # initialization part of MMPC 
   #############################
@@ -21,7 +21,6 @@ perm.mmpc = function(target, dataset, max_k = 3, threshold = 0.05, test = NULL,
       return(NULL);
     }
   }
-  dataInfo = NULL;
   ###################################
   # dataset checking and initialize #
   ###################################
@@ -29,19 +28,6 @@ perm.mmpc = function(target, dataset, max_k = 3, threshold = 0.05, test = NULL,
     if ( sum( class(target) == "matrix") == 1 )  {
       if ( sum( class(target) == "Surv") == 1 )  stop('Invalid dataset class. For survival analysis provide a dataframe-class dataset');      
     }   
-    #check if dataset is an ExpressionSet object of Biobase package
-    # if(class(dataset) == "ExpressionSet") {
-    #get the elements (numeric matrix) of the current ExpressionSet object.
-    #  dataset = Biobase::exprs(dataset);
-    #  dataset = t(dataset);#take the features as columns and the samples as rows
-    #     } else if(is.data.frame(dataset)) {
-    #       if(class(target) != "Surv")
-    #       {
-    #         dataset = as.matrix(dataset);
-    #       }
-    # } else if((class(dataset) != "matrix") & (is.data.frame(dataset) == FALSE) ) {
-    #   stop('Invalid dataset class. It must be either a matrix, a dataframe or an ExpressionSet');
-    # }	
   }
   if( is.null(dataset) || is.null(target) ) {  #|| (dim(as.matrix(target))[2] != 1 & class(target) != "Surv" ))
     stop('invalid dataset or target (class feature) arguments.');
@@ -78,15 +64,13 @@ perm.mmpc = function(target, dataset, max_k = 3, threshold = 0.05, test = NULL,
     if (ncol(target) >= 2 & class(target) != "Surv") {
       if ( (is.null(test) || test == "auto") & (is.null(user_test)) ) {
         test = "testIndMVreg"
-        warning("Multivariate target (ncol(target) >= 2) requires a multivariate test of conditional independence. The testIndMVreg was used. For a user-defined multivariate test, please provide one in the user_test argument.");
       }
     }
   }
   ################################
   # test checking and initialize #
   ################################
-  la <- length( unique( as.numeric(target) ) )
-  
+  la <- length( unique( as.numeric(target) ) ) 
   if (typeof(user_test) == "closure") {
     test = user_test;
   } else {
@@ -98,16 +82,11 @@ perm.mmpc = function(target, dataset, max_k = 3, threshold = 0.05, test = NULL,
       
       #if target is a factor then use the Logistic test
       if ( "factor" %in% class(target) )  {
-        test = "permLogistic";
-        if ( is.ordered(target) )  {
-          dataInfo$target_type = "ordinal";
-        } else {
-          if ( la == 2 ) {
-            dataInfo$target_type = "binary"
-          } else {
-            dataInfo$target_type = "nominal"
-          }
-        }
+        if ( is.ordered(target) &  la > 2 ) {
+          test = "testIndOrdinal"
+        } else if ( !is.ordered(target) & la > 2 ) {
+          test = "testIndMultinom"
+        } else test = "testIndLogistic"
         
       } else if ( ( is.numeric(target) || is.integer(target) ) & survival::is.Surv(target) == FALSE ) {
         
@@ -128,41 +107,30 @@ perm.mmpc = function(target, dataset, max_k = 3, threshold = 0.05, test = NULL,
         test = "permCR";
       } else   stop('Target must be a factor, vector, matrix with at least 2 columns column or a Surv object');
     }
-    
-    if (test == "permLogistic") {
-      if ( is.ordered(target) )  {
-        dataInfo$target_type = "ordinal";
-
-      } else {
-        if ( la == 2 ) {
-          dataInfo$target_type = "binary"
-        } else {
-          dataInfo$target_type = "nominal"
-        }
-      }
-    }
-    #cat("\nConditional independence test used: ");cat(test);cat("\n");
     #available conditional independence tests
     av_tests = c("permFisher", "permReg", "permRQ", "permBeta", "permCR", "permWR", "permER", "permClogit", 
                  "permLogistic", "permPois", "permNB", "permBinom", "permgSquare", "permZIP", "permMVreg", 
-                 "permIGreg", "permGamma", "permNormLog", "permTobit", "permDcor", "auto", NULL);
+                 "permIGreg", "permGamma", "permNormLog", "permTobit", "permDcor", "auto", "permMMReg", 
+                 "permMMFisher", "permMultinom", "permOrdinal", NULL);
     ci_test = test
-    #cat(test)
     if(length(test) == 1) {   #avoid vectors, matrices etc
       test = match.arg(test, av_tests, TRUE);
       #convert to closure type
       if (test == "permFisher") {
-        #an einai posostiaio target
         test = permFisher;
+
+      } else if (test == "permMMFisher") {   
+        test = permMMFisher;
         
-      } else if (test == "permDcor") {   ## It uMMPC the F test
-        #an einai posostiaio target
+      } else if (test == "permDcor") {   
         test = permDcor;
         
-      } else if (test == "permReg") {   ## It uMMPC the F test
-        #an einai posostiaio target
+      } else if (test == "permReg") {   
         test = permReg;
         
+      } else if (test == "permMMReg") {   
+        test = permMMReg;
+        
       } else if(test == "permMVreg") {
         if ( min(target) > 0  &  Rfast::Var( Rfast::rowsums(target) ) == 0 )  target = log( target[, -1]/target[, 1] ) 
         test = permMVreg;
@@ -171,7 +139,6 @@ perm.mmpc = function(target, dataset, max_k = 3, threshold = 0.05, test = NULL,
         test = permBeta;
         
       } else if(test == "permRQ") {   ## quantile regression
-        #an einai posostiaio target
         test = permRQ;
         
       } else if (test == "permIGreg")  {   
@@ -212,6 +179,12 @@ perm.mmpc = function(target, dataset, max_k = 3, threshold = 0.05, test = NULL,
         
       } else if (test == "permLogistic") {
         test = permLogistic;
+		
+      } else if (test == "permMultinom") {
+        test = permMultinom;
+		
+      } else if (test == "permOrdinal") {
+        test = permOrdinal;
         
       } else if (test == "permgSquare") {
         test = permgSquare;
@@ -231,15 +204,11 @@ perm.mmpc = function(target, dataset, max_k = 3, threshold = 0.05, test = NULL,
   if ( (typeof(max_k) != "double") || max_k < 1 )   stop('invalid max_k option');
   if ( max_k > varsize)   max_k <- varsize;
   if ( (typeof(threshold) != "double") || threshold <= 0  || threshold >= 1 )    stop('invalid threshold option');
-  # if(typeof(equal_case)!="double")
-  # {
-  #   stop('invalid equal_case option');
-  # }
   #######################################################################################
   if ( !is.null(user_test) )  ci_test = "user_test";
   #call the main MMPC function after the checks and the initializations
   options(warn = -1)
-  results = perm.Internalmmpc(target, dataset, max_k, threshold, test, ini, wei, user_test, dataInfo, hash, varsize, stat_hash, pvalue_hash, targetID, robust = robust, R = R, ncores = ncores);
+  results = perm.Internalmmpc(target, dataset, max_k, log(threshold), test, ini, wei, user_test, hash, varsize, stat_hash, pvalue_hash, targetID, R = R, ncores = ncores);
   #for testing backward phase
   #   results$selectedVars = c(results$selectedVars,15)
   #   results$selectedVarsOrder = c(results$selectedVarsOrder,15)
@@ -251,13 +220,13 @@ perm.mmpc = function(target, dataset, max_k = 3, threshold = 0.05, test = NULL,
   
   if ( backward & length( varsToIterate ) > 0 ) {
     varsOrder <- results$selectedVarsOrder
-    bc <- mmpcbackphase(target, dataset[, varsToIterate], max_k = max_k, threshold = threshold, test = test, wei = wei, dataInfo = dataInfo, robust = robust, R = R ) 
+    bc <- mmpcbackphase(target, dataset[, varsToIterate], max_k = max_k, threshold = threshold, test = test, wei = wei, R = R ) 
     met <- bc$met
     results$selectedVars <- varsToIterate[met]
     results$selectedVarsOrder <- varsOrder[met]
     results$n.tests <- results$n.tests + bc$counter
   }
-  MMPCoutput <-new("MMPCoutput", selectedVars = results$selectedVars, selectedVarsOrder=results$selectedVarsOrder, hashObject=results$hashObject, pvalues=results$pvalues, stats=results$stats, univ=results$univ, max_k=results$max_k, threshold = results$threshold, n.tests = results$n.tests, runtime=results$runtime, test=ci_test, rob = robust);
+  MMPCoutput <-new("MMPCoutput", selectedVars = results$selectedVars, selectedVarsOrder=results$selectedVarsOrder, hashObject=results$hashObject, pvalues=results$pvalues, stats=results$stats, univ=results$univ, max_k=results$max_k, threshold = results$threshold, n.tests = results$n.tests, runtime=results$runtime, test=ci_test);
   return(MMPCoutput);
 }
 
