@@ -1,5 +1,5 @@
-permBeta = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo=NULL, univariateModels=NULL, hash = FALSE, stat_hash=NULL, pvalue_hash=NULL,
-                       robust=FALSE, threshold = 0.05, R = 999) {
+permBeta = function(target, dataset, xIndex, csIndex, wei = NULL, univariateModels=NULL, hash = FALSE, stat_hash=NULL, pvalue_hash=NULL,
+                       threshold = 0.05, R = 999) {
   #   TESTINDBETA Conditional Independence Test based on beta regression for proportions
   #   provides a p-value PVALUE for the null hypothesis: X independent by target
   #   given CS. The pvalue is calculated by comparing a beta regression model based 
@@ -14,8 +14,6 @@ permBeta = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo=NULL,
   #   xIndex: the index of the variable whose association with the target
   #   must be tested. Can be mixed variables, either continous or categorical
   #   csIndex: the indices of the variables to condition on. 
-  #   this method returns: the pvalue PVALUE, the statistic STAT and a control variable FLAG.
-  #   if FLAG == 1 then the test was performed succesfully 
   csIndex[which(is.na(csIndex))] = 0
   thres <- threshold * R + 1
   
@@ -27,38 +25,32 @@ permBeta = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo=NULL,
     if ( !is.null(stat_hash[[key]]) )  {
       stat = stat_hash[[key]];
       pvalue = pvalue_hash[[key]];
-      flag = 1;
-      results <- list(pvalue = pvalue, stat = stat, flag = flag, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+      results <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
       return(results);
     }
   }
-  #if the test cannot performed succesfully these are the returned values
-  pvalue = 1;
+  pvalue = log(1)
   stat = 0;
-  flag = 0;
-  #if the xIndex is contained in csIndex, x does not bring any new
   #information with respect to cs
   if ( !is.na(match(xIndex, csIndex)) ) {
     if ( hash )  {   #update hash objects
       stat_hash[[key]] <- 0;     #.set(stat_hash , key , 0)
       pvalue_hash[[key]] <- 1;        #.set(pvalue_hash , key , 1)
     }
-    results <- list(pvalue = 1, stat = 0, flag = 1, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+    results <- list(pvalue = 1, stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
     return(results);
   }
   #check input validity
   if (xIndex < 0 || csIndex < 0)  {
     message(paste("error in testIndBeta : wrong input of xIndex or csIndex"))
-    results <- list(pvalue = pvalue, stat = stat, flag = flag, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+    results <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
     return(results);
   }
-  #xIndex = unique(xIndex);
-  #csIndex = unique(csIndex);
-  #extract the data
+  xIndex = unique(xIndex);
+  csIndex = unique(csIndex);
   x = dataset[ , xIndex];
   cs = dataset[ , csIndex];
   if ( length(cs) == 0 || is.na(cs) )  cs = NULL;
-  #if x = any of the cs then pvalue = 1 and flag = 1.
   #That means that the x variable does not add more information to our model due to an exact copy of this in the cs, so it is independent from the target
   if ( length(cs) != 0 )  {
     if ( is.null(dim(cs)[2]) )  {    #cs is a vector
@@ -67,7 +59,7 @@ permBeta = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo=NULL,
           stat_hash[[key]] <- 0;     #.set(stat_hash , key , 0)
           pvalue_hash[[key]] <- 1;     #.set(pvalue_hash , key , 1)
         }
-        results <- list(pvalue = 1, stat = 0, flag = 1 , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+        results <- list(pvalue = 1, stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
         return(results);
       }
     } else { #more than one var
@@ -77,7 +69,7 @@ permBeta = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo=NULL,
             stat_hash[[key]] <- 0;    #.set(stat_hash , key , 0)
             pvalue_hash[[key]] <- 1;    #.set(pvalue_hash , key , 1)
           }
-          results <- list(pvalue = 1, stat = 0, flag = 1, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+          results <- list(pvalue = 1, stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
           return(results);
         }
       }
@@ -93,8 +85,7 @@ permBeta = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo=NULL,
     if ( !is.null(univariateModels) )   {
       pvalue = univariateModels$pvalue[[xIndex]];
       stat = univariateModels$stat[[xIndex]];
-      flag = univariateModels$flag[[xIndex]];
-      results <- list(pvalue = pvalue, stat = stat, flag = flag, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+      results <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
       return(results);
     }
     #Fitting beta regressions
@@ -110,7 +101,7 @@ permBeta = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo=NULL,
       step <- step + ( bit2$loglik > lik2 )
       j <- j + 1
     }
-    pvalue <-  (step + 1) / (R + 1) 
+    pvalue <-  log( (step + 1) / (R + 1) )
   } else {
     #Fitting beta regressions
     fit1 <- beta.reg(target, cs, wei = wei)
@@ -126,8 +117,8 @@ permBeta = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo=NULL,
     step <- step + ( bit2$loglik > lik2 )
     j <- j + 1
   }
-  pvalue <-  (step + 1) / (R + 1) 
-  flag = 1;
+  pvalue <-  log( (step + 1) / (R + 1) )
+
   #update hash objects
   if ( hash )  {
     stat_hash[[key]] <- stat;    #.set(stat_hash , key , stat)
@@ -135,9 +126,8 @@ permBeta = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo=NULL,
   }
   #last error check
   if (is.na(pvalue) || is.na(stat) ) {
-    pvalue = 1;
+    pvalue = log(1)
     stat = 0;
-    flag = 0;
   } else {
     #update hash objects
     if ( hash )  {
@@ -146,32 +136,15 @@ permBeta = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo=NULL,
     }
   }
   #testerrorcaseintrycatch(4);
-  results <- list(pvalue = pvalue, stat = stat, flag = flag, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+  results <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
   return(results);
 },
 error=function(cond) {
-#   message(paste("error in try catch of the testIndBeta test"))
-#   message("Here's the original error message:")
-#   message(cond)
-#   for debug
-#   print("\nxIndex = \n");
-#   print(xIndex);
-#   print("\ncsindex = \n");
-#   print(csIndex);
-#   error case
-#  stop();
-  pvalue = 1;
+  pvalue = log(1)
   stat = 0;
-  flag = 0;
-  results <- list(pvalue = pvalue, stat = stat, flag = flag, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+  results <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
   return(results);
 },
-#   warning=function(cond) {
-#     #do nothing, or
-#     message(paste("Warning in the testIndBeta testL"))
-#     message("Here's the original warning message:")
-#     message(cond)
-#   },
 finally={}
   )
   
