@@ -1,5 +1,5 @@
-permWR = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo=NULL, univariateModels=NULL, hash = FALSE, stat_hash=NULL, pvalue_hash=NULL,
-                  robust=FALSE, threshold = 0.05, R = 999){
+permWR = function(target, dataset, xIndex, csIndex, wei = NULL, univariateModels=NULL, hash = FALSE, stat_hash=NULL, pvalue_hash=NULL,
+                  threshold = 0.05, R = 999){
   # Conditional independence test based on the Log Likelihood ratio test
   if (!survival::is.Surv(target) )   stop('The survival test can not be performed without a Surv object target');
   csIndex[which(is.na(csIndex))] = 0;
@@ -12,19 +12,17 @@ permWR = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo=NULL, u
     if (is.null(stat_hash[[key]]) == FALSE) {
       stat = stat_hash[[key]];
       pvalue = pvalue_hash[[key]];
-      flag = 1;
-      results <- list(pvalue = pvalue, stat = stat, flag = flag, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+      results <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
       return(results);
     }
   }
   #initialization: these values will be returned whether the test cannot be carried out
-  pvalue = 1;
+  pvalue = log(1);
   stat = 0;
-  flag = 0;
-  results <- list(pvalue = pvalue, stat = stat, flag = flag, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+  results <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
   weibull_results = NULL;
-  weibull_results_full = NULL;   # timeIndex = dim(dataset)[2];
-  event = target[,2]            # dataInfo$event;
+  weibull_results_full = NULL;   
+  event = target[,2]            
   #retrieving the data
   x = dataset[ , xIndex];
   #if the censored indicator is empty, a dummy variable is created
@@ -33,7 +31,7 @@ permWR = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo=NULL, u
       if (is.na(csIndex) || length(csIndex) == 0 || csIndex == 0) {
         weibull_results <- survival::survreg(target ~ x, weights = wei)
         stat = 2 * abs( diff(weibull_results$loglik) )
-		     if (stat > 0) {
+		  if (stat > 0) {
           step <- 0
           j <- 1	
           n <- length(x)
@@ -44,8 +42,8 @@ permWR = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo=NULL, u
             step <- step + ( stat2 > stat )
             j <- j + 1
           }
-          pvalue <- (step + 1) / (R + 1)         
-		}  
+          pvalue <- log( (step + 1) / (R + 1) )        
+		} else pvalue <- log(1)
         
       } else {
         weibull_results <- survival::survreg(target ~ ., data = as.data.frame( dataset[ , csIndex] ), weights = wei) 
@@ -65,11 +63,9 @@ permWR = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo=NULL, u
           pvalue <- (step + 1) / (R + 1)
 		}  
       }  
-      flag = 1;
       if ( is.na(pvalue) || is.na(stat) ) {
-        pvalue = 1;
+        pvalue = log(1);
         stat = 0;
-        flag = 0;
       } else {
         #update hash objects
         if( hash )  {
@@ -78,6 +74,6 @@ permWR = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo=NULL, u
         }
       }
       #testerrorcaseintrycatch(4);
-      results <- list(pvalue = pvalue, stat = stat, flag = flag , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+      results <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
       return(results);
 }
