@@ -1,8 +1,7 @@
-testIndMVreg = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo=NULL, univariateModels=NULL , hash = FALSE, stat_hash=NULL, 
- pvalue_hash=NULL, robust=FALSE)
-  {
+testIndMVreg = function(target, dataset, xIndex, csIndex, wei = NULL, univariateModels=NULL , hash = FALSE, stat_hash=NULL, 
+ pvalue_hash=NULL) {
   # TESTINDMVREG Conditional Independence Test for multivariate continous class variables 
-  # PVALUE = TESTINDMVREG(Y, DATA, XINDEX, CSINDEX, DATAINFO)
+  # PVALUE = TESTINDMVREG(Y, DATA, XINDEX, CSINDEX)
   # This test provides a p-value PVALUE for the NULL hypothesis H0 which is
   # X is independent by TARGET given CS. The pvalue is calculated following
   # nested models
@@ -12,9 +11,7 @@ testIndMVreg = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo=N
   #   DATASET: a numeric data matrix containing the variables for performing the test. They can be mixed variables. 
   #   XINDEX: the index of the variable whose association with the target we want to test. 
   #   CSINDEX: the indices if the variable to condition on. 
-  #   DATAINFO: information on the structure of the data
-  # this method returns: the pvalue PVALUE, the statistic STAT and a control variable FLAG.
-  # if FLAG == 1 then the test was performed succesfully
+  # this method returns: the pvalue PVALUE, the statistic STAT.
   # References
   # [1] Norman R. Draper and Harry Smith. Applied Regression 
   # Analysis, Wiley, New York, USA, third edition, May 1998.
@@ -23,7 +20,6 @@ testIndMVreg = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo=N
   #if the test cannot performed succesfully these are the returned values
   pvalue = log(1);
   stat = 0;
-  flag = 0;
   csIndex[which(is.na(csIndex))] = 0;
   if ( hash )  {
     csIndex2 = csIndex[which(csIndex!=0)]
@@ -33,8 +29,7 @@ testIndMVreg = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo=N
     if ( !is.null(stat_hash[[key]]) )   {
       stat = stat_hash[[key]];
       pvalue = pvalue_hash[[key]];
-      flag = 1;
-      results <- list(pvalue = pvalue, stat = stat, flag = flag , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+      results <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
       return(results);
     }
   }
@@ -44,23 +39,21 @@ testIndMVreg = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo=N
       stat_hash$key <- 0;#.set(stat_hash , key , 0)
       pvalue_hash$key <- log(1);#.set(pvalue_hash , key , 1)
     }
-    results <- list(pvalue = log(1), stat = 0, flag = 1 , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+    results <- list(pvalue = log(1), stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
     return(results);
   }
   
   #check input validity
   if(xIndex < 0 || csIndex < 0) {
     message(paste("error in testIndMVreg : wrong input of xIndex or csIndex"))
-    results <- list(pvalue = pvalue, stat = stat, flag = flag , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+    results <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
     return(results);
   }
   
   xIndex = unique(xIndex);
   csIndex = unique(csIndex);
-  #extract the data
   x = dataset[ , xIndex];
   cs = dataset[ , csIndex];
-  #if x = any of the cs then pvalue = 1 and flag = 1.
   #That means that the x variable does not add more information to our model due to an exact copy of this in the cs, so it is independent from the target
   if ( length(cs) != 0 ) {
     if ( is.null(dim(cs)[2]) )  {     #cs is a vector
@@ -69,7 +62,7 @@ testIndMVreg = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo=N
           stat_hash$key <- 0;#.set(stat_hash , key , 0)
           pvalue_hash$key <- log(1);#.set(pvalue_hash , key , 1)
         }
-        results <- list(pvalue = log(1), stat = 0, flag = 1, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+        results <- list(pvalue = log(1), stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
         return(results);
       }
     } else { #more than one var
@@ -79,7 +72,7 @@ testIndMVreg = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo=N
             stat_hash$key <- 0;#.set(stat_hash , key , 0)
             pvalue_hash$key <- log(1);#.set(pvalue_hash , key , 1)
           }
-          results <- list(pvalue = log(1), stat = 0, flag = 1, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+          results <- list(pvalue = log(1), stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
           return(results);
         }
       }
@@ -90,8 +83,7 @@ testIndMVreg = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo=N
     if ( !is.null(univariateModels) )  {
       pvalue = univariateModels$pvalue[[xIndex]];
       stat = univariateModels$stat[[xIndex]];
-      flag = univariateModels$flag[[xIndex]];
-      results <- list(pvalue = pvalue, stat = stat, flag = flag, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+      results <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
       return(results);
     }
     #compute the relationship between x,target directly
@@ -100,7 +92,6 @@ testIndMVreg = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo=N
     if ( any( is.na( fit2$coefficients ) ) ) {
     stat <- 0
 	  pvalue <- log(1)
-	  flag <- 1
 	} else {
 	  fit1 = lm(target ~., data = data.frame(dataset[ , csIndex] ), weights = wei )  
     mod = anova( fit1, fit2 ) 
@@ -108,13 +99,11 @@ testIndMVreg = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo=N
     df1 = abs(mod[2, 2])
     df2 = mod[2, 1]
     pvalue = pf(stat, df1, df2, lower.tail= FALSE, log.p = TRUE)
-    flag = 1;
   }
   #last error check
   if ( is.na(pvalue) || is.na(stat) ) {
     pvalue = log(1);
     stat = 0;
-    flag = 0;
   } else {
     #update hash objects
     if( hash )  {
@@ -123,6 +112,6 @@ testIndMVreg = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo=N
     }
   }
   #testerrorcaseintrycatch(4);
-  results <- list(pvalue = pvalue, stat = stat, flag = flag , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+  results <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
   return(results);
 }
\ No newline at end of file
