@@ -1,7 +1,7 @@
-testIndRQ = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo=NULL, univariateModels=NULL , hash = FALSE, stat_hash=NULL, pvalue_hash=NULL,robust=FALSE) 
-  {
+testIndRQ = function(target, dataset, xIndex, csIndex, wei = NULL, univariateModels=NULL, 
+                     hash = FALSE, stat_hash=NULL, pvalue_hash=NULL) {
   # TESTINDRQ Conditional Independence Test for numerical class variables 
-  # PVALUE = TESTINDRQ(Y, DATA, XINDEX, CSINDEX, DATAINFO)
+  # PVALUE = TESTINDRQ(Y, DATA, XINDEX, CSINDEX)
   # This test provides a p-value PVALUE for the NULL hypothesis H0 which is
   # X is independent by TARGET given CS. The pvalue is calculated following
   # nested models
@@ -11,9 +11,7 @@ testIndRQ = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo=NULL
   #   DATASET: a numeric data matrix containing the variables for performing the test. They can be mixed variables. 
   #   XINDEX: the index of the variable whose association with the target we want to test. 
   #   CSINDEX: the indices if the variable to condition on. 
-  #   DATAINFO: information on the structure of the data
-  # this method returns: the pvalue PVALUE, the statistic STAT and a control variable FLAG.
-  # if FLAG == 1 then the test was performed succesfully
+  # this method returns: the pvalue PVALUE, the statistic STAT.
   # References
   # [1] Koenker, Roger. Quantile regression. New York, Cambridge        
   # university press, 2005.
@@ -21,7 +19,6 @@ testIndRQ = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo=NULL
   #if the test cannot performed succesfully these are the returned values
   pvalue = log(1);
   stat = 0;
-  flag = 0;
   csIndex[which(is.na(csIndex))] = 0;
   
   if( hash )  {
@@ -32,8 +29,7 @@ testIndRQ = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo=NULL
     if(is.null(stat_hash[[key]]) == FALSE)  {
       stat = stat_hash[[key]];
       pvalue = pvalue_hash[[key]];
-      flag = 1;
-      results <- list(pvalue = pvalue, stat = stat, flag = flag , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+      results <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
       return(results);
     }
   }
@@ -44,22 +40,20 @@ testIndRQ = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo=NULL
       stat_hash[[key]] <- 0;#.set(stat_hash , key , 0)
       pvalue_hash[[key]] <- log(1);#.set(pvalue_hash , key , 1)
     }
-    results <- list(pvalue = log(1), stat = 0, flag = 1 , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+    results <- list(pvalue = log(1), stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
     return(results);
   }
   #check input validity
   if (xIndex < 0 || csIndex < 0)  {
     message(paste("error in testIndRQ : wrong input of xIndex or csIndex"))
-    results <- list(pvalue = pvalue, stat = stat, flag = flag , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+    results <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
     return(results);
   }
   
   xIndex = unique(xIndex);
   csIndex = unique(csIndex);
-  #extract the data
   x = dataset[ , xIndex];
   cs = dataset[ , csIndex];
-  #if x = any of the cs then pvalue = 1 and flag = 1.
   #That means that the x variable does not add more information to our model due to an exact copy of this in the cs, so it is independent from the target
   if ( length(cs) != 0 ) {
     if ( is.null(dim(cs)[2]) )  {   #cs is a vector
@@ -68,7 +62,7 @@ testIndRQ = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo=NULL
           stat_hash[[key]] <- 0;#.set(stat_hash , key , 0)
           pvalue_hash[[key]] <- log(1);#.set(pvalue_hash , key , 1)
         }
-        results <- list(pvalue = log(1), stat = 0, flag = 1 , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+        results <- list(pvalue = log(1), stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
         return(results);
       }
     } else { #more than one var
@@ -78,7 +72,7 @@ testIndRQ = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo=NULL
             stat_hash[[key]] <- 0;#.set(stat_hash , key , 0)
             pvalue_hash[[key]] <- log(1);#.set(pvalue_hash , key , 1)
           }
-          results <- list(pvalue = log(1), stat = 0, flag = 1 , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+          results <- list(pvalue = log(1), stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
           return(results);
         }
       }
@@ -89,7 +83,6 @@ testIndRQ = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo=NULL
   #if the conditioning set (cs) is empty, we use a simplified formula
   if (length(cs) == 0) {
     #compute the relationship between x,target directly
-    #fit1 = fita
     options(warn = -1)
     fit1 = quantreg::rq(target ~ 1, weights = wei)
     fit2 = quantreg::rq(target ~ x, weights = wei)
@@ -106,44 +99,31 @@ testIndRQ = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo=NULL
     df2 = as.numeric( mod[[1]][2] )
     stat = as.numeric( mod[[1]][3] )
     pvalue = pf(stat, df1, df2, lower.tail = FALSE, log.p = TRUE)
-    flag = 1;
   
   #last error check
   if ( is.na(pvalue) || is.na(stat) )  {
     pvalue = log(1);
     stat = 0;
-    flag = 0;
   } else {
     #update hash objects
     if ( hash ) {
-      stat_hash[[key]] <- stat;#.set(stat_hash , key , stat)
-      pvalue_hash[[key]] <- pvalue;#.set(pvalue_hash , key , pvalue)
+      stat_hash[[key]] <- stat;       #.set(stat_hash , key , stat)
+      pvalue_hash[[key]] <- pvalue;       #.set(pvalue_hash , key , pvalue)
     }
   }
   #testerrorcaseintrycatch(4);
-  results <- list(pvalue = pvalue, stat = stat, flag = flag , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+  results <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
   return(results);
   
 },
 error=function(cond) {
-#   message(paste("error in try catch of the testIndRQ test"))
-#   message("Here's the original error message:")
-#   message(cond)
-#   
-#    for debug
-#    print("\nxIndex = \n");
-#    print(xIndex);
-#    print("\ncsindex = \n");
-#    print(csIndex);
-#   stop();
   #error case
   pvalue = log(1);
   stat = 0;
-  flag = 0;
-  results <- list(pvalue = pvalue, stat = stat, flag = flag , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+  results <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
   return(results);
 },
 finally={}
-  )    
-  return(res);
+)    
+return(res);
 }
\ No newline at end of file
