@@ -1,4 +1,4 @@
-univregs <- function(target, dataset, targetID = -1, test = NULL, user_test = NULL, wei = NULL, dataInfo = NULL, robust = FALSE, ncores = 1) {
+univregs <- function(target, dataset, targetID = -1, test = NULL, user_test = NULL, wei = NULL, ncores = 1) {
   
   univariateModels <- list();
   dm <- dim(dataset)
@@ -17,9 +17,9 @@ univregs <- function(target, dataset, targetID = -1, test = NULL, user_test = NU
   la <- length( unique(target) )
   
 if ( !is.null(user_test) ) {
-  univariateModels <- univariateScore(target, dataset, test = user_test, wei, dataInfo = dataInfo, targetID, robust)
+  univariateModels <- univariateScore(target, dataset, test = user_test, wei, targetID)
 
-} else if ( identical(test, testIndFisher)  &  robust == FALSE )  { ## Pearson's correlation 
+} else if ( identical(test, testIndFisher) )  { ## Pearson's correlation 
   a <- as.vector( cor(target, dataset) )
   dof <- rows - 3; #degrees of freedom
   wa <- 0.5 * log( (1 + a) / (1 - a) ) * sqrt(dof)
@@ -51,7 +51,7 @@ if ( !is.null(user_test) ) {
   univariateModels$stat = mod[, 1]
   univariateModels$pvalue = mod[, 2]
 
-} else if ( identical(test, testIndReg)  &  robust  ) {  ## M (Robust) linear regression
+} else if ( identical(test, testIndMMReg) ) {  ## M (Robust) linear regression
   fit1 = MASS::rlm(target ~ 1, maxit = 2000, method = "MM")
   lik1 = as.numeric( logLik(fit1) )
   lik2 = numeric(cols)
@@ -69,7 +69,6 @@ if ( !is.null(user_test) ) {
     univariateModels$pvalue = pchisq(stat, dof, lower.tail = FALSE, log.p = TRUE)
 
   } else {
-    
     cl <- makePSOCKcluster(ncores)
     registerDoParallel(cl)
     mod <- foreach(i = 1:cols, .combine = rbind, .packages = "MASS") %dopar% {
@@ -84,7 +83,7 @@ if ( !is.null(user_test) ) {
     univariateModels$pvalue = pchisq(stat, dof, lower.tail = FALSE, log.p = TRUE)
   }   
   
-} else if ( identical(test, testIndReg)  &  !robust  &  !is.null(wei) ) {  ## Weighted linear regression
+} else if ( identical(test, testIndReg)  &  !is.null(wei) ) {  ## Weighted linear regression
   
   univariateModels = list();
   stat = pval = numeric(cols)
@@ -116,17 +115,17 @@ if ( !is.null(user_test) ) {
     univariateModels$pvalue = mod[, 2]
   }   
   
-} else if ( identical(test, testIndReg)  &  !robust &  is.matrix(dataset)  &  is.null(wei) ) {  ## linear regression
-  mod = Rfast::univglms(target, dataset, logged = TRUE) 
+} else if ( identical(test, testIndReg) &  is.matrix(dataset)  &  is.null(wei) ) {  ## linear regression
+  mod = Rfast::univglms(target, dataset, oiko = "normal", logged = TRUE) 
   univariateModels$stat = mod[, 1]
   univariateModels$pvalue = mod[, 2]
 
-} else if ( identical(test, testIndReg)  &  !robust &  is.data.frame(dataset) ) {  ## linear regression
+} else if ( identical(test, testIndReg)  &  is.data.frame(dataset) ) {  ## linear regression
   mod <- Rfast::regression(dataset, target, logged = TRUE)
   univariateModels$stat = mod[, 1]
   univariateModels$pvalue = mod[, 2]
 
-} else if ( identical(test, testIndMVreg)  &  !robust  &  !is.null(wei) ) {  ## Weighted linear regression
+} else if ( identical(test, testIndMVreg)  &  !is.null(wei) ) {  ## Weighted linear regression
   
   univariateModels = list();
   stat = pval = numeric(cols)
@@ -158,80 +157,7 @@ if ( !is.null(user_test) ) {
     univariateModels$pvalue = mod[, 2]
   }   
   
-} else if ( identical(test, testIndSpeedglm) ) {  ## big glm regresssion
-  if ( is.factor(target)  ||  la == 2 ) {
-    
-    target <- as.numeric( as.factor(target) ) - 1  
-    if ( is.matrix(dataset)  &  is.null(wei)  ) {
-      mod <- Rfast::univglms(target, dataset, oiko = "binomial", logged = TRUE)
-      stat <- mod[, 1]
-      pval <- mod[, 2]
-      
-    } else {
-      stat <- dof <- numeric(cols)
-      for ( i in 1:cols ) {
-        fit2 <- speedglm::speedglm(target ~., data = data.frame(dataset[, i]), family = binomial(logit), weights = wei )
-        stat[i] <- fit2$deviance
-        dof[i] <- length( coef(fit2) )     
-      }
-      stat <- abs( stat - fit2$nulldev )
-      pval <- pchisq(stat, dof, lower.tail = FALSE, log.p = TRUE )
-    }  
-    
-  } else if ( la > 2  &  sum(round(target) - target) == 0 ) {
-    ina <- 1:cols
-
-    if (  is.matrix(dataset)  &  is.null(wei) ) {
-      mod <- Rfast::univglms(target, dataset, oiko = "poisson", logged = TRUE)
-      stat <- mod[, 1]
-      pval <- mod[, 2]
-      
-    } else {
-      stat <- dof <- numeric(cols)
-      for ( i in ina ) {
-        fit2 <- speedglm::speedglm(target ~., data = data.frame(dataset[, i]), family = poisson(log), weights = wei )
-        stat[i] <- fit2$deviance
-        dof[i] <- length( coef(fit2) )
-      }
-      stat <- abs( stat - fit2$nulldev )
-      pval <- pchisq(stat, dof, lower.tail = FALSE, log.p = TRUE )
-    } 
-    
-  } else {
-     
-    if ( is.null(wei) ) {
-      if ( is.matrix(dataset) )  {
-        mod <- Rfast::univglms(target, dataset, oiko = "normal", logged = TRUE) 
-      }  
-      #if ( is.data.frame(dataset) )   mod <- Rfast::regression(dataset, target)
-      stat <- mod[1, ]
-      pval <- pf(stat, mod[2, ], rows - mod[2, ] - 1, lower.tail = FALSE, log.p = TRUE)
-	  if ( is.data.frame(dataset) ) {
-      stat <- numeric(cols)
-		  pval <- numeric(cols)  
-	    for (i in 1:cols) {
-        mod <- anova( lm(target ~ dataset[, i]) )
-		    stat[i] <- mod[1, 5]
-        pval[i] <- pf(stat[i], mod[1, 1], mod[2, 1], lower.tail = FALSE, log.p = TRUE)  		   
-      } 
-      mat <- cbind(1:cols, pval, stat)	 
-	  } 	 
-    } else {
-      stat <- dof <- numeric(cols)
-      for ( i in 1:cols ) {
-        fit2 <- speedglm::speedlm(target ~., data = data.frame(dataset[, i]), weights = wei )
-        suma <- summary(fit2)[[ 13 ]]
-        stat[i] <- suma[1]
-        dof[i] <- suma[2]
-      }
-      pval <- pf(stat, dof, rows - dof - 1, lower.tail = FALSE, log.p = TRUE)
-    } 
-    
-  }
-  univariateModels$stat = stat
-  univariateModels$pvalue = pval
-
-} else if ( identical(test, testIndLogistic)  &  is.ordered(target) ) {  ## ordinal regression
+} else if ( identical(test, testIndOrdinal) ) {  ## ordinal regression
   lik2 <- numeric(cols)
   dof <- numeric(cols)
   fit1 <- ordinal::clm(target ~ 1, weights = wei)
@@ -266,7 +192,7 @@ if ( !is.null(user_test) ) {
 
   }
   
-} else if ( identical(test, testIndLogistic) == TRUE  &  la > 2  ) {  ## multinomial regression
+} else if ( identical(test, testIndMultinom) ) {  ## multinomial regression
   
   target = as.factor( as.numeric( target ) );
   lik2 = numeric(cols)
@@ -300,13 +226,13 @@ if ( !is.null(user_test) ) {
     univariateModels$pvalue = pchisq(stat, mod[, 2] - df1, lower.tail = FALSE, log.p = TRUE)
   }
   
-} else if ( identical(test, testIndLogistic)  &  la == 2  &  is.matrix(dataset)  &  is.null(wei) ) {  ## logistic regression
+} else if ( identical(test, testIndLogistic)  &  is.matrix(dataset)  &  is.null(wei) ) {  ## logistic regression
   if ( is.factor(target) )   target <- as.numeric(target) - 1
   mod <- Rfast::univglms( target, dataset, oiko = "binomial", logged = TRUE )
   univariateModels$stat = mod[, 1]
   univariateModels$pvalue = mod[, 2]
 
-} else if ( identical(test, testIndLogistic)  &  la == 2  &  ( !is.null(wei)  ||  is.data.frame(dataset)  ) ) {  ## Logistic regression
+} else if ( identical(test, testIndLogistic)  & !is.null(wei)  ||  is.data.frame(dataset) ) {  ## Logistic regression
   fit1 = glm(target ~ 1, binomial, weights = wei)
   lik1 = fit1$deviance
   lik2 = numeric(cols)
@@ -336,7 +262,7 @@ if ( !is.null(user_test) ) {
     univariateModels$pvalue = pchisq(stat, mod[, 2], lower.tail = FALSE, log.p = TRUE)
   }
   
-} else if ( identical(test, testIndBinom) ) {  ## Logistic regression
+} else if ( identical(test, testIndBinom) ) {  ## Binomial regression
   wei <- target[, 2] 
   y <- target[, 1] / wei
   fit1 = glm(y ~ 1, binomial, weights = wei)
@@ -709,10 +635,75 @@ if ( !is.null(user_test) ) {
     univariateModels$pvalue = pchisq(stat, mod[ ,2], lower.tail = FALSE, log.p = TRUE)
   }
   
+} else if ( identical(test, testIndQBinom)   ) {  ## Quasi Binomial regression
+
+  fit1 = glm(target ~ 1, family = quasibinomial(link = logit), weights = wei)
+  lik1 = fit1$deviance
+  lik2 = numeric(cols)
+  dof = numeric(cols)
+  ina <- 1:cols
+  phi <- numeric(cols)
+  
+  if ( ncores <= 1 | is.null(ncores) ) {
+    for ( i in ina ) {
+      fit2 = glm( target ~ dataset[, i], family = quasibinomial(link = logit), weights = wei )
+      lik2[i] = fit2$deviance
+      phi[i] = summary(fit2)[[ 14 ]]
+      dof[i] = length( fit2$coefficients)
+    }
+    stat = (lik1 - lik2) / (dof - 1) / phi
+    univariateModels$stat = stat
+    univariateModels$pvalue = pf(stat, dof - 1, rows - dof, lower.tail = FALSE, log.p = TRUE)
+  
+  } else {
+    cl <- makePSOCKcluster(ncores)
+    registerDoParallel(cl)
+    mod <- foreach(i = ina, .combine = rbind) %dopar% {
+      fit2 = glm( target ~ dataset[, i], family = quasibinomial(link = logit), weights = wei )
+      return( c(fit2$deviance, length( fit2$coefficients ), summary(fit2)[[14]] ) )
+    }
+    stopCluster(cl)
+    stat = as.vector( lik1 - mod[, 1] ) / (mod[, 2] - 1) / mod[, 3] 
+    univariateModels$stat = stat
+    univariateModels$pvalue = pf(stat, mod[, 2] - 1, rows - mod[, 2], lower.tail = FALSE, log.p = TRUE)
+  }
+  
+} else if ( identical(test, testIndQPois)   ) {  ## Quasi Poisson regression
+  
+  fit1 = glm(target ~ 1, family = quasipoisson(link = log), weights = wei)
+  lik1 = fit1$deviance
+  lik2 = numeric(cols)
+  dof = numeric(cols)
+  ina <- 1:cols
+  phi <- numeric(cols)
+  
+  if ( ncores <= 1 | is.null(ncores) ) {
+    for ( i in ina ) {
+      fit2 = glm( target ~ dataset[, i], family = quasipoisson(link = log), weights = wei )
+      lik2[i] = fit2$deviance
+      phi[i] = summary(fit2)[[ 14 ]]
+      dof[i] = length( fit2$coefficients)
+    }
+    stat = (lik1 - lik2) / (dof - 1) / phi
+    univariateModels$stat = stat
+    univariateModels$pvalue = pf(stat, dof - 1, rows - dof, lower.tail = FALSE, log.p = TRUE)
+    
+  } else {
+    cl <- makePSOCKcluster(ncores)
+    registerDoParallel(cl)
+    mod <- foreach(i = ina, .combine = rbind) %dopar% {
+      fit2 = glm( target ~ dataset[, i], family = quasipoisson(link = log), weights = wei )
+      return( c(fit2$deviance, length( fit2$coefficients ), summary(fit2)[[14]] ) )
+    }
+    stopCluster(cl)
+    stat = as.vector( lik1 - mod[, 1] ) / (mod[, 2] - 1) / mod[, 3] 
+    univariateModels$stat = stat
+    univariateModels$pvalue = pf(stat, mod[, 2] - 1, rows - mod[, 2], lower.tail = FALSE, log.p = TRUE)
+  }
+  
 }  else   univariateModels <- NULL
   
   if ( !is.null(univariateModels) )  {
-    univariateModels$flag = numeric(cols) + 1  
     if (targetID != - 1) {
       univariateModels$stat[targetID] = 0
       univariateModels$pvalue[targetID] = log(1)
